==> istio-model-v1alpha3-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ReadinessProbeFluent<A extends ReadinessProbeFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildHealthCheckMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsReadinessProbeHealthCheckMethod getHealthCheckMethod();
  public IsReadinessProbeHealthCheckMethod buildHealthCheckMethod();
  public A withHealthCheckMethod(IsReadinessProbeHealthCheckMethod healthCheckMethod);
  public Boolean hasHealthCheckMethod();
  public A withReadinessProbeTcpSocketHealthCheckMethod(ReadinessProbeTcpSocket readinessProbeTcpSocketHealthCheckMethod);
  public ReadinessProbeFluent.ReadinessProbeTcpSocketHealthCheckMethodNested<A> withNewReadinessProbeTcpSocketHealthCheckMethod();
  public ReadinessProbeFluent.ReadinessProbeTcpSocketHealthCheckMethodNested<A> withNewReadinessProbeTcpSocketHealthCheckMethodLike(ReadinessProbeTcpSocket item);
  public A withReadinessProbeExecHealthCheckMethod(ReadinessProbeExec readinessProbeExecHealthCheckMethod);
  public ReadinessProbeFluent.ReadinessProbeExecHealthCheckMethodNested<A> withNewReadinessProbeExecHealthCheckMethod();
  public ReadinessProbeFluent.ReadinessProbeExecHealthCheckMethodNested<A> withNewReadinessProbeExecHealthCheckMethodLike(ReadinessProbeExec item);
  public A withReadinessProbeHttpGetHealthCheckMethod(ReadinessProbeHttpGet readinessProbeHttpGetHealthCheckMethod);
  public ReadinessProbeFluent.ReadinessProbeHttpGetHealthCheckMethodNested<A> withNewReadinessProbeHttpGetHealthCheckMethod();
  public ReadinessProbeFluent.ReadinessProbeHttpGetHealthCheckMethodNested<A> withNewReadinessProbeHttpGetHealthCheckMethodLike(ReadinessProbeHttpGet item);
  public Integer getFailureThreshold();
  public A withFailureThreshold(Integer failureThreshold);
  public Boolean hasFailureThreshold();
  public Integer getInitialDelaySeconds();
  public A withInitialDelaySeconds(Integer initialDelaySeconds);
  public Boolean hasInitialDelaySeconds();
  public Integer getPeriodSeconds();
  public A withPeriodSeconds(Integer periodSeconds);
  public Boolean hasPeriodSeconds();
  public Integer getSuccessThreshold();
  public A withSuccessThreshold(Integer successThreshold);
  public Boolean hasSuccessThreshold();
  public Integer getTimeoutSeconds();
  public A withTimeoutSeconds(Integer timeoutSeconds);
  public Boolean hasTimeoutSeconds();
  public interface ReadinessProbeTcpSocketHealthCheckMethodNested<N> extends Nested<N>,ReadinessProbeTcpSocketFluent<ReadinessProbeFluent.ReadinessProbeTcpSocketHealthCheckMethodNested<N>>{
    public N and();
    public N endReadinessProbeTcpSocketHealthCheckMethod();
    
  }
  public interface ReadinessProbeExecHealthCheckMethodNested<N> extends Nested<N>,ReadinessProbeExecFluent<ReadinessProbeFluent.ReadinessProbeExecHealthCheckMethodNested<N>>{
    public N and();
    public N endReadinessProbeExecHealthCheckMethod();
    
  }
  public interface ReadinessProbeHttpGetHealthCheckMethodNested<N> extends Nested<N>,ReadinessProbeHttpGetFluent<ReadinessProbeFluent.ReadinessProbeHttpGetHealthCheckMethodNested<N>>{
    public N and();
    public N endReadinessProbeHttpGetHealthCheckMethod();
    
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ReadinessProbeFluent<A extends ReadinessProbeFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildHealthCheckMethod instead.
   * @return The buildable object.
   */
  @Deprecated
  public IsReadinessProbeHealthCheckMethod getHealthCheckMethod();
  public IsReadinessProbeHealthCheckMethod buildHealthCheckMethod();
  public A withHealthCheckMethod(IsReadinessProbeHealthCheckMethod healthCheckMethod);
  public Boolean hasHealthCheckMethod();
  public A withReadinessProbeTcpSocketHealthCheckMethod(ReadinessProbeTcpSocket readinessProbeTcpSocketHealthCheckMethod);
  public ReadinessProbeFluent.ReadinessProbeTcpSocketHealthCheckMethodNested<A> withNewReadinessProbeTcpSocketHealthCheckMethod();
  public ReadinessProbeFluent.ReadinessProbeTcpSocketHealthCheckMethodNested<A> withNewReadinessProbeTcpSocketHealthCheckMethodLike(ReadinessProbeTcpSocket item);
  public A withReadinessProbeExecHealthCheckMethod(ReadinessProbeExec readinessProbeExecHealthCheckMethod);
  public ReadinessProbeFluent.ReadinessProbeExecHealthCheckMethodNested<A> withNewReadinessProbeExecHealthCheckMethod();
  public ReadinessProbeFluent.ReadinessProbeExecHealthCheckMethodNested<A> withNewReadinessProbeExecHealthCheckMethodLike(ReadinessProbeExec item);
  public A withReadinessProbeHttpGetHealthCheckMethod(ReadinessProbeHttpGet readinessProbeHttpGetHealthCheckMethod);
  public ReadinessProbeFluent.ReadinessProbeHttpGetHealthCheckMethodNested<A> withNewReadinessProbeHttpGetHealthCheckMethod();
  public ReadinessProbeFluent.ReadinessProbeHttpGetHealthCheckMethodNested<A> withNewReadinessProbeHttpGetHealthCheckMethodLike(ReadinessProbeHttpGet item);
  public Integer getFailureThreshold();
  public A withFailureThreshold(Integer failureThreshold);
  public Boolean hasFailureThreshold();
  public Integer getInitialDelaySeconds();
  public A withInitialDelaySeconds(Integer initialDelaySeconds);
  public Boolean hasInitialDelaySeconds();
  public Integer getPeriodSeconds();
  public A withPeriodSeconds(Integer periodSeconds);
  public Boolean hasPeriodSeconds();
  public Integer getSuccessThreshold();
  public A withSuccessThreshold(Integer successThreshold);
  public Boolean hasSuccessThreshold();
  public Integer getTimeoutSeconds();
  public A withTimeoutSeconds(Integer timeoutSeconds);
  public Boolean hasTimeoutSeconds();
  public interface ReadinessProbeTcpSocketHealthCheckMethodNested<N> extends Nested<N>,ReadinessProbeTcpSocketFluent<ReadinessProbeFluent.ReadinessProbeTcpSocketHealthCheckMethodNested<N>>{
    public N and();
    public N endReadinessProbeTcpSocketHealthCheckMethod();
    
  }
  public interface ReadinessProbeExecHealthCheckMethodNested<N> extends Nested<N>,ReadinessProbeExecFluent<ReadinessProbeFluent.ReadinessProbeExecHealthCheckMethodNested<N>>{
    public N and();
    public N endReadinessProbeExecHealthCheckMethod();
    
  }
  public interface ReadinessProbeHttpGetHealthCheckMethodNested<N> extends Nested<N>,ReadinessProbeHttpGetFluent<ReadinessProbeFluent.ReadinessProbeHttpGetHealthCheckMethodNested<N>>{
    public N and();
    public N endReadinessProbeHttpGetHealthCheckMethod();
    
  }
  
}
